<?php

/**
 * Add Form Database Tables.
 *
 * @package Auto Dealer Forms
 */

function createFormDataBaseTables()
{
    global $wpdb;
    $charset = $wpdb->get_charset_collate();
    $table_prefix = $wpdb->prefix . 'adf_';

    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

    // Define table creation queries

    dbDelta("CREATE TABLE IF NOT EXISTS {$table_prefix}contact_submissions (
        id INT AUTO_INCREMENT PRIMARY KEY,
        full_name VARCHAR(100) NOT NULL,
        phone_number VARCHAR(15) NOT NULL,
        email VARCHAR(100) NOT NULL,
        contact_message TEXT NOT NULL,
        newsletter_consent TINYINT(1) NOT NULL DEFAULT 0,
        privacy_consent TINYINT(1) NOT NULL DEFAULT 0,
        submission_date TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP
    )");

    dbDelta("CREATE TABLE IF NOT EXISTS {$table_prefix}service_submissions (
        id INT AUTO_INCREMENT PRIMARY KEY,
        full_name VARCHAR(255) NOT NULL,
        email VARCHAR(255) NOT NULL,
        phone_number VARCHAR(20) NOT NULL,
        preferred_contact_method VARCHAR(10) NOT NULL,
        preferred_date DATE NOT NULL,
        preferred_contact_time VARCHAR(20) NOT NULL,
        vehicle_make VARCHAR(100) NOT NULL,
        vehicle_model VARCHAR(100) NOT NULL,
        vehicle_year INT NOT NULL,
        serviced_before TINYINT(1) NOT NULL,
        service_message TEXT,
        newsletter_consent TINYINT(1) NOT NULL,
        privacy_consent TINYINT(1) NOT NULL,
        submission_date TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP
    )");

    dbDelta("CREATE TABLE IF NOT EXISTS {$table_prefix}finder_submissions (
        id INT AUTO_INCREMENT PRIMARY KEY,
        vehicle_sale_class VARCHAR(10) NOT NULL,
        vehicle_year INT NOT NULL,
        vehicle_make VARCHAR(100) NOT NULL,
        vehicle_model VARCHAR(100) NOT NULL,
        vehicle_style VARCHAR(10) NOT NULL,
        vehicle_transmission VARCHAR(10) NOT NULL,
        vehicle_odometer INT NOT NULL,
        vehicle_price DECIMAL(10,2) NOT NULL,
        full_name VARCHAR(255) NOT NULL,
        email VARCHAR(255) NOT NULL,
        phone_number VARCHAR(20) NOT NULL,
        preferred_contact_method VARCHAR(10) NOT NULL,
        message TEXT NOT NULL,
        newsletter_consent TINYINT(1) NOT NULL,
        privacy_consent TINYINT(1) NOT NULL,
        submission_date TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP
    )");

    dbDelta("CREATE TABLE IF NOT EXISTS {$table_prefix}seller_submissions (
       id INT AUTO_INCREMENT PRIMARY KEY,
       vehicle_year INT NOT NULL,
       vehicle_make VARCHAR(100) NOT NULL,
       vehicle_model VARCHAR(100) NOT NULL,
       vehicle_transmission VARCHAR(10) NOT NULL,
       vehicle_odometer VARCHAR(50) NOT NULL,
       seller_full_name VARCHAR(255) NOT NULL,
       seller_phone_number VARCHAR(20) NOT NULL,
       seller_email VARCHAR(255) NOT NULL,
       preferred_contact_method VARCHAR(10) NOT NULL,
       seller_message TEXT NOT NULL,
       newsletter_consent TINYINT(1) NOT NULL,
       privacy_consent TINYINT(1) NOT NULL,
       submission_date TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP
   )");

    dbDelta("CREATE TABLE IF NOT EXISTS {$table_prefix}trade_in_submissions (
       id INT AUTO_INCREMENT PRIMARY KEY,
       vehicle_make VARCHAR(100) NOT NULL,
       vehicle_model VARCHAR(100) NOT NULL,
       min_year INT NOT NULL,
       max_year INT NOT NULL,
       min_odometer INT NOT NULL,
       max_odometer INT NOT NULL,
       comments TEXT NOT NULL,
       trade_in_year INT NOT NULL,
       trade_in_make VARCHAR(100) NOT NULL,
       trade_in_model VARCHAR(100) NOT NULL,
       trade_in_vin VARCHAR(50) NOT NULL,
       trade_in_mileage INT NOT NULL,
       trade_in_transmission VARCHAR(10) NOT NULL,
       first_name VARCHAR(255) NOT NULL,
       last_name VARCHAR(255) NOT NULL,
       phone_number VARCHAR(20) NOT NULL,
       email VARCHAR(255) NOT NULL,
       postal_code VARCHAR(10) NOT NULL,
       preferred_contact_method VARCHAR(10) NOT NULL,
       newsletter_consent TINYINT(1) NOT NULL,
       privacy_consent TINYINT(1) NOT NULL,
       submission_date TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP
   )");
}
