<?php

/**
 * Add Form Validation.
 *
 * @package Auto Dealer Forms
 */


function contactUsValidation()
{
    if ($_SERVER['REQUEST_METHOD'] === "POST") {
        if (
            isset($_POST['contact_us_privacy_consent']) &&
            isset($_POST['contact_us_full_name']) &&
            isset($_POST['contact_us_phone_number']) &&
            isset($_POST['contact_us_email']) &&
            isset($_POST['contact_us_message'])
        ) {
            // Sanitize and validate form data
            $full_name = sanitize_text_field($_POST['contact_us_full_name']);
            $phone_number = sanitize_text_field($_POST['contact_us_phone_number']);
            $email = sanitize_email($_POST['contact_us_email']);
            $message = sanitize_textarea_field($_POST['contact_us_message']);

            // Regular expression patterns
            $name_pattern = "/^[a-zA-Z\s]+$/";
            $email_pattern = "/^\S+@\S+\.\S+$/";
            $phone_pattern = "/^\d{3}-\d{3}-\d{4}$/";

            // Check for invalid email
            if (!preg_match($email_pattern, $email)) {
                // Redirect back to the form page and keep fields populated
                wp_redirect(add_query_arg('error', 'invalid_email', $_SERVER['HTTP_REFERER']));
                exit;
            }

            // Check for valid full name
            if (!preg_match($name_pattern, $full_name)) {
                // Redirect back to the form page and keep fields populated
                wp_redirect(add_query_arg('error', 'invalid_full_name', $_SERVER['HTTP_REFERER']));
                exit;
            }

            // Check for valid phone number
            if (!preg_match($phone_pattern, $phone_number)) {
                // Redirect back to the form page and keep fields populated
                wp_redirect(add_query_arg('error', 'invalid_phone_number', $_SERVER['HTTP_REFERER']));
                exit;
            }

            // Insert data into the database
            global $wpdb;
            $table_name = $wpdb->prefix . 'adf_contact_submissions';
            $result = $wpdb->insert(
                $table_name,
                array(
                    'full_name' => $full_name,
                    'phone_number' => $phone_number,
                    'email' => $email,
                    'contact_message' => $message,
                ),
                array('%s', '%s', '%s', '%s')
            );

            if (!$result) {
                // Redirect back to the form page and keep fields populated
                wp_redirect(add_query_arg('error', 'database_error', $_SERVER['HTTP_REFERER']));
                exit;
            }

            // Construct email message
            $to = 'prospect@harplabs.com'; // Replace with your email address
            $subject = 'New Contact Form Submission';
            $body = "Full Name: " . htmlspecialchars($full_name) . "\n";
            $body .= "Phone Number: " . htmlspecialchars($phone_number) . "\n";
            $body .= "Email: " . htmlspecialchars($email) . "\n";
            $body .= "Message: " . htmlspecialchars($message) . "\n";
            $headers = array('Content-Type: text/html; charset=UTF-8');

            // Send email
            wp_mail($to, $subject, $body, $headers);

            // Redirect after successful submission
            wp_redirect(esc_url(get_permalink('4')));
            exit;
        }
    }
}
