<?php

/**
 * Contact Us Form template.
 *
 * @package Auto Dealer Forms
 */

?>

<!-- Contact Form -->
<form id="contact_us" name="contact_us" method="POST" action="<?= esc_url(admin_url('admin-post.php')); ?>" class="w-full bg-white px-4 2xl:px-0 py-10 rounded-md">

    <input type="hidden" name="action" value="contactus">

    <div style="display:none;">
        <label for="contact_us_email_field">Contact Use Email Field</label>
        <input type="hidden" id="contact_us_email_field" name="contact_us_email_field">
        <input type="hidden" id="contact_us_timestamp" name="contact_us_timestamp" value="<?= time(); ?>">
    </div>

    <!-- Add Timestamp Field -->

    <!-- Contact Information -->
    <h2 class="text-xl lg:text-3xl font-bold mb-2 uppercase">Get In Touch Us</h2>
    <div class="sm:grid sm:grid-cols-2 md:grid-cols-3 gap-4">

        <!-- Contact Information -->
        <div class="mb-2">
            <label for="contact_us_full_name" class="block text-gray-700">Full Name</label>
            <input placeholder="Enter your full name" type="text" id="contact_us_full_name" name="contact_us_full_name" class="rounded-md form-input mt-1 block w-full" required>
            <span id="fullname_error" class="text-red-600 hidden">Please enter a valid full name</span>
        </div>
        <div class="mb-2">
            <label for="contact_us_phone_number" class="block text-gray-700">Phone Number</label>
            <input placeholder="123-456-7891" type="tel" id="contact_us_phone_number" name="contact_us_phone_number" class="rounded-md form-input mt-1 block w-full" required>
            <span id="phone_error" class="text-red-600 hidden">Please enter a valid phone number</span>
        </div>
        <div class="mb-2">
            <label for="contact_us_email" class="block text-gray-700">Email</label>
            <input placeholder="Enter your best email" type="email" id="contact_us_email" name="contact_us_email" class="rounded-md form-input mt-1 block w-full" required>
            <span id="email_error" class="text-red-600 hidden">Please enter a valid email address</span>
        </div>

        <div class="mb-2 sm:col-span-2 md:col-span-3">
            <label for="contact_us_message" class="block text-gray-700">Message</label>
            <textarea placeholder="Enter your message..." id="contact_us_message" name="contact_us_message" class="rounded-md h-44 lg:h-56 form-textarea mt-1 block w-full" required></textarea>
        </div>

        <!-- Consent Checkboxes -->
        <div class="mb-2 sm:col-span-2 md:col-span-3 flex items-center">
            <input type="checkbox" id="contact_us_newsletter_consent" name="contact_us_newsletter_consent" class="rounded-sm form-checkbox">
            <label for="contact_us_newsletter_consent" class="ml-2 text-gray-700">I agree to receive periodical offers, newsletter, safety and recall updates from the dealership. Consent can be withdrawn at any time.</label>
        </div>
        <div class="mb-2 sm:col-span-2 md:col-span-3 flex items-center">
            <input type="checkbox" id="contact_us_privacy_consent" name="contact_us_privacy_consent" class="rounded-sm form-checkbox" required>
            <label for="contact_us_privacy_consent" class="ml-2 text-gray-700">By submitting this information, you are accepting that it may be collected, used and disclosed as described in our <a class="underline font-medium" href="<?= esc_url(get_permalink('181')); ?>">privacy policy</a>.</label>
        </div>

        <!-- Submit Button -->
        <div class="lg:col-span-3">
            <button id="contact-submit" type="submit" aria-label="Contact Us Form" class="w-full bg-red-500 hover:bg-red-800 transition-colors duration-300 text-white font-medium py-2 px-4 rounded">
                Submit<i class="bi-send-check ml-2"></i>
            </button>
        </div>

    </div>

</form>


<script>
    document.addEventListener('DOMContentLoaded', function() {

        document.getElementById('contact_us_full_name').addEventListener('input', function() {
            var fullName = this.value.trim();
            var regex = /^[a-zA-Z]+(([',. -][a-zA-Z ])?[a-zA-Z]*)*$/;
            var errorSpan = document.getElementById('fullname_error');
            if (!regex.test(fullName)) {
                errorSpan.classList.remove('hidden');
            } else {
                errorSpan.classList.add('hidden');
            }
        });

        document.getElementById('contact_us_phone_number').addEventListener('input', function() {
            var phoneNumber = this.value.trim();
            var regex = /^\d{3}-\d{3}-\d{4}$/;
            var errorSpan = document.getElementById('phone_error');
            if (!regex.test(phoneNumber)) {
                errorSpan.classList.remove('hidden');
            } else {
                errorSpan.classList.add('hidden');
            }
        });

        document.getElementById('contact_us_email').addEventListener('input', function() {
            var email = this.value.trim();
            var regex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
            var errorSpan = document.getElementById('email_error');
            if (!regex.test(email)) {
                errorSpan.classList.remove('hidden');
            } else {
                errorSpan.classList.add('hidden');
            }
        });

        // Check hp and submission timestamp before form submission
        document.getElementById('contact_us').addEventListener('submit', function(event) {
            var emailPotField = document.getElementById('contact_us_email_field').value;
            var timestampField = parseInt(document.getElementById('contact_us_timestamp').value);
            var currentTime = Math.floor(Date.now() / 1000); // Current time in seconds

            // If emailPot field is filled or submission is too quick (less than 6 seconds), prevent form submission
            if (emailPotField !== '' || (currentTime - timestampField) < 6) {
                event.preventDefault();
                console.log('Potential bot submission detected!');
                // You can take further actions here, like displaying an error message or logging the attempt
                document.getElementById('contact-submit').disabled = true;
            }
        });
    });
</script>