<?php

/**
 * Schedule Service Form template.
 *
 * @package Auto Dealer Forms
 */

include(plugin_dir_path(__DIR__) . '/includes/service_data.php');

?>

<!-- Schedule Service Form -->
<form id="schedule_service_form" name="schedule_service_form" method="post" action="<?= esc_url(get_permalink('54')); ?>" class="w-full bg-white px-4 2xl:px-0 py-4 lg:py-8 rounded-md">

    <!-- Vehicle Search -->
    <h2 class="text-xl lg:text-3xl font-bold mb-2 uppercase">Book Service</h2>
    <div class="sm:grid sm:grid-cols-2 md:grid-cols-3 gap-4 mb-4">

        <input type="hidden" name="schedule_service_action" value="submit_car_trade_in_form">

        <!-- Contact Information -->
        <div class="mb-2">
            <label for="schedule_service_full_name" class="block text-gray-700">Full Name</label>
            <input autocomplete="off" placeholder="Enter your first name" type="text" id="schedule_service_full_name" name="schedule_service_full_name" class="rounded-md form-input mt-1 block w-full" required>
        </div>
        <div class="mb-2">
            <label for="schedule_service_email" class="block text-gray-700">Email</label>
            <input autocomplete="off" placeholder="Enter your best email" type="email" id="schedule_service_email" name="schedule_service_email" class="rounded-md form-input mt-1 block w-full" required>
        </div>
        <div class="mb-2">
            <label for="schedule_service_phone_number" class="block text-gray-700">Phone Number</label>
            <input autocomplete="off" placeholder="Enter your phone number" type="tel" id="schedule_service_phone_number" name="schedule_service_phone_number" class="rounded-md form-input mt-1 block w-full" required>
        </div>
        <div class="mb-2">
            <label for="schedule_service_preferred_contact" class="block text-gray-700">Preferred Contact Method</label>
            <select id="schedule_service_preferred_contact" name="schedule_service_preferred_contact" class="rounded-md form-select mt-1 block w-full" required>
                <option value="" disabled selected>Select Preferred Contact Method</option>
                <option value="phone">Phone</option>
                <option value="email">Email</option>
                <option value="text">Text</option>
            </select>
        </div>
        <div class="mb-2">
            <label for="schedule_service_preferred_date" class="block text-gray-700">Preferred Date</label>
            <input autocomplete="off" placeholder="yyyy-mm-dd" type="date" id="schedule_service_preferred_date" name="schedule_service_preferred_date" class="rounded-md form-input mt-1 block w-full" required>
        </div>

        <div class="mb-2">
            <label for="schedule_service_preferred_contact_time" class="block text-gray-700">Best Time To Contact</label>
            <select id="schedule_service_preferred_contact_time" name="schedule_service_preferred_contact_time" class="rounded-md form-select mt-1 block w-full" required>
                <option value="" disabled selected>Select Best Contact Time</option>
                <option value="anytime">Anytime</option>
                <option value="morning">Morning</option>
                <option value="afternoon">Afternoon</option>
                <option value="evening">Evening</option>
            </select>
        </div>

        <!-- Vehicle Details -->
        <div class="mb-2">
            <label for="schedule_service_vehicle_make" class="block text-gray-700">Vehicle Make</label>
            <input autocomplete="off" placeholder="Ford, Honda, Subaru..." type="text" id="schedule_service_vehicle_make" name="schedule_service_vehicle_make" class="rounded-md form-input mt-1 block w-full" required>
        </div>
        <div class="mb-2">
            <label for="schedule_service_vehicle_model" class="block text-gray-700">Vehicle Model</label>
            <input autocomplete="off" placeholder="F-150, Civic, Outback..." type="text" id="schedule_service_vehicle_model" name="schedule_service_vehicle_model" class="rounded-md form-input mt-1 block w-full" required>
        </div>
        <div class="mb-2">
            <label for="schedule_service_vehicle_year" class="block text-gray-700">Vehicle Year</label>
            <input autocomplete="off" placeholder="2013" type="number" maxlength="4" id="schedule_service_vehicle_year" name="schedule_service_vehicle_year" class="rounded-md form-input mt-1 block w-full" required>
        </div>

    </div>

    <h2 class="text-xl lg:text-3xl font-bold mb-2 uppercase">Services</h2>
    <div class="grid grid-cols-2 lg:grid-cols-4 mb-4">
        <?php foreach ($auto_services as $service) { ?>
            <div class="flex items-center space-x-2">
                <input type="checkbox" id="schedule_service_<?= strtolower(str_replace(' ', '_', $service['service_name'])) ?>" name="schedule_service_<?= strtolower(str_replace(' ', '_', $service['service_name'])) ?>" class="rounded-sm form-checkbox" value="<?= $service['service_name'] ?>">
                <label for="schedule_service_<?= strtolower(str_replace(' ', '_', $service['service_name'])) ?>" class=" text-gray-700"><?= $service['service_name'] ?></label>
            </div>
        <?php } ?>
    </div>

    <h2 class="text-xl lg:text-3xl font-bold mb-2 uppercase">Additional Details</h2>
    <div>
        <div class="flex items-center space-x-2 mb-4">
            <input type="checkbox" id="schedule_service_vehicle_serviced_before" name="schedule_service_vehicle_serviced_before" class="rounded-sm form-checkbox">
            <label for="schedule_service_vehicle_serviced_before" class=" text-gray-700">I've had my vehicle serviced by Rogers Motors before</label>
        </div>

        <div class="mb-2 sm:col-span-2 md:col-span-3">
            <label for="schedule_service_message" class="block text-gray-700">Message</label>
            <textarea autocomplete="off" placeholder="Leave your message..." id="schedule_service_message" name="schedule_service_message" class="rounded-md h-44 lg:h-56 form-textarea mt-1 block w-full"></textarea>
        </div>

    </div>

    <!-- Consent Checkboxes -->
    <div class="mb-2 sm:col-span-2 md:col-span-3 flex items-center">
        <input type="checkbox" id="schedule_service_newsletter_consent" name="schedule_service_newsletter_consent" class="rounded-sm form-checkbox">
        <label for="schedule_service_newsletter_consent" class="ml-2 text-gray-700">I agree to receive periodical offers, newsletter, safety and recall updates from the dealership. Consent can be withdrawn at any time.</label>
    </div>
    <div class="mb-2 sm:col-span-2 md:col-span-3 flex items-center">
        <input type="checkbox" id="schedule_service_privacy_consent" name="schedule_service_privacy_consent" class="rounded-sm form-checkbox" required>
        <label for="schedule_service_privacy_consent" class="ml-2 text-gray-700">By submitting this information, you are accepting that it may be collected, used and disclosed as described in our <a class="underline font-medium" href="<?= esc_url(get_permalink('181')); ?>">privacy policy</a>.</label>
    </div>

    <!-- Submit Button -->
    <div class="lg:col-span-3">
        <button type="submit" aria-label="Schedule Service Form" class="w-full bg-red-500 hover:bg-red-800 transition-colors duration-300 text-white font-medium py-2 px-4 rounded">
            Submit<i class="bi-send-check ml-2"></i>
        </button>
    </div>

</form>