class MakeFilter {
    constructor(make, dataStore) {
        this.value = make.text;
        this.count = make.count;
        this.dataStore = dataStore;
        this.checkbox = null;
        this.models = make.models.map(model=> filterManager.createModelFilter({ text: model.model, count: model.count, trims: model.trims, parent: this.value, checked: false },  this.dataStore));
        this.checked = make.checked;
        this.formField = null;
        // this.initCheckbox();
        this.subscribers = [];
        this.models.forEach(m => {
            m.subscribe(m=> initTrimContainer(m))
        });
    }

    initCheckbox() {
        const makeListBlock = document.createElement('div');
        const dynamicId = `autocart_${this.value.toLowerCase().replace(/\s/g, '-').replace(/\./g, '')}`;
        const dynamicClass = `autocart_term_${this.value.toLowerCase().replace(/\s/g, '-').replace(/\./g, '')}`;
        makeListBlock.innerHTML = `
            <li class="w-full rounded-t-lg  flex items-center justify-between transition duration-400 autocart-filters">
                <div class="flex items-center mdc-form-field flex-wrap justify-between items-start flex-row w-full ${dynamicClass} hover:text-red-500">
                    <label for="${dynamicId}" class="text-sm font-medium text-gray-900 dark:text-gray-300 transition duration-400 font-normal text-base">${this.value}</label>
                    <span class="autocart_count text-gray-500 ml-2 transition duration-400 font-normal text-base">
                        (${this.count})
                    </span>
                </div>
                <div class="mdc-checkbox mdc-theme-primary">
                    <input type="checkbox" class="mdc-checkbox__native-control ${dynamicClass}" id="${dynamicId}" />
                    <div class="mdc-checkbox__background rounded-md">
                        <svg class="mdc-checkbox__checkmark" viewBox="0 0 24 24">
                            <path class="mdc-checkbox__checkmark-path" fill="none" d="M1.73,12.91 8.1,19.28 22.79,4.59"/>
                        </svg>
                        <div class="mdc-checkbox__mixedmark"></div>
                    </div>
                    <div class="mdc-checkbox__ripple p-2"></div>
                </div>
            </li>`;
        
        this.checkbox = makeListBlock.querySelector('.mdc-checkbox');
        if (this.checkbox) {
            const checkboxElement = this.checkbox.querySelector(`.mdc-checkbox__native-control.${dynamicClass}`);
            this.checkbox = new mdc.checkbox.MDCCheckbox(this.checkbox);
            this.formField = new mdc.formField.MDCFormField(makeListBlock.querySelector(`.mdc-form-field.${dynamicClass}`));
            this.formField.input = checkboxElement;
            this.checkbox.listen('change', () => this.handleCheckboxChange());
        } else {
            console.error('Checkbox element not found:', dynamicId);
        }

       this.markCheckboxIfValueFiltered()

        return makeListBlock;
    }

    markCheckboxIfValueFiltered() {
        if (this.checked) {
            this.checkbox.checked = true;
        } else {
            let ifAlreadyFiltered = this.dataStore.getAppliedFilters().find(filter => filter.type == "make");
            if (ifAlreadyFiltered) {
                if (ifAlreadyFiltered.values.includes(this.value)) {
                    this.checkbox.checked = true;
                }
            }
        }
        // }
        // let ifAlreadyFiltered = this.dataStore.getAppliedFilters().find(filter=>filter.type == "make");
        // if(ifAlreadyFiltered){
        //     if(ifAlreadyFiltered.values.includes(this.value)){
        //         this.checkbox.checked = true;
        //     }
        // }
    }

    handleCheckboxChange() {
        shouldUpdateFilters = false;        
        const isChecked = this.checkbox.checked;        
        if (isChecked) {
            this.dataStore.addFilter('make', this.value);
            // this.updateModelFilters(this.value);
        } else {
            this.dataStore.removeFilter('make', this.value);
        }

        this.checked = isChecked;
        this.models.forEach(model=>model.uncheckCheckbox())
        createBodyTypeList(this.dataStore.filterVehicles());
        createTransmissionList(this.dataStore.filterVehicles());
        createExteriorList(this.dataStore.filterVehicles());
        this.notifySubscribers();
    }

    generateCardHTML() {
        if(this.checked){
            // this.checkbox.checked = true;
            setTimeout(() => {
                shouldUpdateFilters = false;        

                this.dataStore.addFilter('make', this.value);
                this.notifySubscribers();
            }, 100);
            
        }
        return this.initCheckbox();

        
        
    }

    updateModelFilters(value) {
        this.models.forEach(model => {
            model.setParentFilter(value)
        });
    }

  
    uncheckCheckbox() {
        if (this.checkbox) {
            this.checkbox.checked = false;
            this.handleCheckboxChange();
            // this.checkbox.dispatchEvent(new Event('change'));
        }

       
    }  
    
    notifySubscribers() {
        this.subscribers.forEach(subscriber => subscriber(this));
    }

    subscribe(subscriber) {
        this.subscribers.push(subscriber);
    }

    unsubscribe(subscriber) {
        this.subscribers = this.subscribers.filter(sub => sub !== subscriber);
    }
}