class NavControl {
  constructor() {
    this.toggleMenuBtn = document.getElementById('toggle-nav');
    this.toggleSlideOutMenu = document.getElementById('slide-out-menu');
    this.accordions = document.querySelectorAll('#slide-out-menu .accordion');
    this.toggleSearchBtn = document.getElementById('toggle-search');
    this.headerSearch = document.getElementById('header-search');
    this.hoursDropdownToggle = document.getElementById('hours-dropdown-toggle');
    this.todaysBusinessHoursEl = document.getElementById(
      'todays-business-hours'
    );
    this.businessHoursMenu = this.hoursDropdownToggle.nextElementSibling;
    this.init();
  }

  init() {
    document.addEventListener('DOMContentLoaded', () => {
      // Add link click listeners
      this.addLinkClickListener('a');
      // Open and Close the Nav Menu
      this.toggleMenuBtn.addEventListener('click', () => this.toggleNavMenu());
      // Open and Close the Nav Search
      // this.toggleSearchBtn.addEventListener('click', () => this.toggleSearch());

      document.addEventListener('click', (event) =>
        this.handleOutsideClick(event)
      );

      this.businessHours();
    });
  }

  addLinkClickListener(selector) {
    this.links = document.querySelectorAll(selector);
    this.links.forEach((link) => {
      link.addEventListener('click', (e) => {
        if (link.href === window.location.href) {
          return;
        }

        if (this.toggleMenuBtn.classList.contains('active')) {
          this.navControl.toggleNavMenu();
        }
      });
    });
  }

  isExternalLink(link) {
    const currentDomain = window.location.hostname;
    const linkDomain = link.hostname;

    return linkDomain !== currentDomain;
  }

  toggleNavMenu() {
    this.toggleMenuBtn.classList.toggle('active');
    this.toggleSlideOutMenu.classList.toggle('open');
    document.body.classList.toggle('noScroll');
    this.collapseAllAccordions();
  }

  toggleSearch() {
    this.headerSearch.classList.toggle('active');
    this.headerSearch.querySelector('input').focus();

    if (this.headerSearch.classList.contains('active')) {
      this.headerSearch.querySelector('input').value = '';
    }

    if (this.toggleMenuBtn.classList.contains('active')) {
      this.toggleNavMenu();
    }
  }

  collapseAllAccordions() {
    setTimeout(() => {
      this.accordions.forEach((accordion) => {
        accordion.classList.remove('active');
      });
    }, 600);
  }

  handleOutsideClick(event) {
    if (
      !this.toggleMenuBtn.contains(event.target) &&
      !this.toggleSlideOutMenu.contains(event.target) &&
      !event.target.classList.contains('accordion')
    ) {
      // Click is outside the menu and toggle button
      this.toggleMenuBtn.classList.remove('active');
      this.toggleSlideOutMenu.classList.remove('open');
      document.body.classList.remove('noScroll');
    }

    if (
      !this.hoursDropdownToggle.contains(event.target) &&
      !this.hoursDropdownToggle.classList.contains('hidden')
    ) {
      // Click is outside the business hours toggle button
      this.businessHoursMenu.classList.add('hidden');
    }

    //   if (
    //     !this.toggleSearchBtn.contains(event.target) &&
    //     !this.headerSearch.contains(event.target)
    //   ) {
    //     // Click is input the menu and search button
    //     this.toggleSearchBtn.classList.remove('active');
    //     this.headerSearch.classList.remove('active');
    //     document.body.classList.remove('noScroll');
    //   }
  }

  // Handle Business Hours
  businessHours() {
    const dayOfWeek = new Date().getDay();
    const defaultHours = 'Open Today from 10:00am - 6:00pm';
    let todaysBusinessHours;

    switch (dayOfWeek) {
      case 0: // Sunday
        todaysBusinessHours = 'We are closed today.';
        break;
      case 6: // Saturday
        todaysBusinessHours = 'Open Today from 10:00am - 5:00pm';
        break;
      default: // Monday to Friday
        todaysBusinessHours = defaultHours;
        break;
    }

    this.todaysBusinessHoursEl.innerHTML = todaysBusinessHours;

    this.hoursDropdownToggle.addEventListener('click', () => {
      this.businessHoursMenu.classList.toggle('hidden');
    });
  }
}

export default NavControl;
